==> kom%2B%2B-0.2.tar.gz: kom++-0.2/libkom++/maps.cc <==
// Create-on-demand map of mappings for conferences.
//
// $Id: maps.cc,v 1.4 1994/07/16 17:44:24 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <assert.h>
#include "conference.h"
#include "maps.h"
#include "connection.h"
#include "map-cache.h"

Maps::Maps()
  : cache(NULL)
{
}

Maps::Maps(const Conferences&c)
  : cache(new Map_cache(c))
{
}

Maps::~Maps()
{
}

Maps & 
Maps::operator = (const Maps &m)
{
    cache = m.cache;
    return *this;
}

void
Maps::set_conferences(const Conferences&c)
{
    assert(cache == NULL);
    cache = new Map_cache(c);
}

Connection *
Maps::connection() const
{
    return cache->connection();
}

    
Text_mapping
Maps::operator[](Conf_no c) const
{
    return cache->get(c);
}

Map_cache *
Maps::read_map_cache() const
{
    return cache;
}

==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libkom++/maps.cc <==
// Create-on-demand map of mappings for conferences.
//
// $Id: maps.cc,v 1.5 1994/08/01 21:54:05 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <assert.h>
#include "conference.h"
#include "maps.h"
#include "connection.h"
#include "map-cache.h"

Maps::Maps()
  : cache(NULL)
{
}

Maps::Maps(const Conferences&c)
  : cache(new Map_cache(c))
{
}

Maps::~Maps()
{
    delete cache;
}

// Maps & 
// Maps::operator = (const Maps &m)
// {
//     // FIXME: gr Map_cache till ett referensrknande objekt
//     cache = m.cache;
//     return *this;
// }

void
Maps::set_conferences(const Conferences&c)
{
    assert(cache == NULL);
    cache = new Map_cache(c);
}

Connection *
Maps::connection() const
{
    return cache->connection();
}

    
Text_mapping
Maps::operator[](Conf_no c) const
{
    return cache->get(c);
}

Map_cache *
Maps::read_map_cache() const
{
    return cache;
}
